# Change Log

## [v2.0](https://github.com/thewizardplusplus/white-generator/tree/v2.0) (2024-10-19)

**Closed issues:**

- Refactoring:
  - Support for separate options in the classes from the `types.py` file [\#25](https://github.com/thewizardplusplus/white-generator/issues/25)
  - Cover the project code with unit tests [\#26](https://github.com/thewizardplusplus/white-generator/issues/26)
  - Use the type hints over the project code [\#27](https://github.com/thewizardplusplus/white-generator/issues/27)
- New features:
  - Support for working with a default font [\#31](https://github.com/thewizardplusplus/white-generator/issues/31)
  - Support for negative text rectangle coordinates \(with wrapping\) [\#32](https://github.com/thewizardplusplus/white-generator/issues/32)
  - Support for resizing a background image [\#36](https://github.com/thewizardplusplus/white-generator/issues/36)
- Option enhancements:
  - Support for a default output path [\#29](https://github.com/thewizardplusplus/white-generator/issues/29)
  - Support for disabling the protection against duplicate meme texts [\#30](https://github.com/thewizardplusplus/white-generator/issues/30)
  - Store notes in the home directory by constant path [\#33](https://github.com/thewizardplusplus/white-generator/issues/33)
- Misc.:
  - Migrate to the `pyproject.toml` configuration [\#23](https://github.com/thewizardplusplus/white-generator/issues/23)
  - Update the dependencies [\#24](https://github.com/thewizardplusplus/white-generator/issues/24)
  - Add the `Makefile` with the basic commands [\#34](https://github.com/thewizardplusplus/white-generator/issues/34)

**Fixed bugs:**

- Fix the bug with the generation expression [\#28](https://github.com/thewizardplusplus/white-generator/issues/28)
- Font descent is not taken into account when obtaining a bounding box of text [\#39](https://github.com/thewizardplusplus/white-generator/issues/39)

## [v1.3](https://github.com/thewizardplusplus/white-generator/tree/v1.3) (2017-06-28)

**Closed issues:**

- Make a log colorful [\#15](https://github.com/thewizardplusplus/white-generator/issues/15)
- Process of the KeyboardInterrupt exception [\#16](https://github.com/thewizardplusplus/white-generator/issues/16)
- Use an uppercase in names of services files [\#18](https://github.com/thewizardplusplus/white-generator/issues/18)
- Prepare the package for a publication [\#20](https://github.com/thewizardplusplus/white-generator/issues/20)
- Correct the usage description [\#21](https://github.com/thewizardplusplus/white-generator/issues/21)
- Versions:
  - Specify a package version in the \_\_init\_\_.py file [\#12](https://github.com/thewizardplusplus/white-generator/issues/12)
  - Specify a minimal Python version in the setup.py file [\#13](https://github.com/thewizardplusplus/white-generator/issues/13)
  - Specify dependencies versions in the setup.py file [\#14](https://github.com/thewizardplusplus/white-generator/issues/14)
  - Refactor the version message [\#17](https://github.com/thewizardplusplus/white-generator/issues/17)
  - Automatically set a version number in the setup.py file [\#19](https://github.com/thewizardplusplus/white-generator/issues/19)

**Fixed bugs:**

- Use a context manager on a working with a database [\#22](https://github.com/thewizardplusplus/white-generator/issues/22)

## [v1.2](https://github.com/thewizardplusplus/white-generator/tree/v1.2) (2017-03-09)

**Closed issues:**

- Separate the code to some subpackages [\#9](https://github.com/thewizardplusplus/white-generator/issues/9)
- Add an installation via pip tool [\#7](https://github.com/thewizardplusplus/white-generator/issues/7)

**Fixed bugs:**

- Include a logging initialization into a try-except block [\#11](https://github.com/thewizardplusplus/white-generator/issues/11)
- Close a database connection [\#10](https://github.com/thewizardplusplus/white-generator/issues/10)
- Correct an exit code on an error [\#8](https://github.com/thewizardplusplus/white-generator/issues/8)

## [v1.1](https://github.com/thewizardplusplus/white-generator/tree/v1.1) (2017-02-15)

**Closed issues:**

- Fit a text into a specified rectangle [\#6](https://github.com/thewizardplusplus/white-generator/issues/6)
- Add text limits options [\#5](https://github.com/thewizardplusplus/white-generator/issues/5)
- Wrap a long text [\#4](https://github.com/thewizardplusplus/white-generator/issues/4)
- Add a support of an image background [\#3](https://github.com/thewizardplusplus/white-generator/issues/3)
- Add text align options [\#2](https://github.com/thewizardplusplus/white-generator/issues/2)
- Add text position options [\#1](https://github.com/thewizardplusplus/white-generator/issues/1)

## [v1.0](https://github.com/thewizardplusplus/white-generator/tree/v1.0) (2017-01-23)

_This change log was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)._
